ad_page_contract {
  @cvs-id $Id: if.tcl,v 1.3.28.1 2015/09/10 08:22:11 gustafn Exp $
} -properties {
  users:multirow
}

set x 5

set y 10

set n "Fred's Flute"

set z ""


set bool_t_p t
set bool_1_p 1

set bool_f_p f
set bool_0_p 0

# Local variables:
#    mode: tcl
#    tcl-indent-level: 4
#    indent-tabs-mode: nil
# End:
